@@ -1,4 +1,4 @@
-#ident "$Id: faxq-helper.c,v 4.14 2003/06/28 20:43:40 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxq-helper.c,v 4.17 2014/02/02 13:44:26 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxq-helper.c
  *
@@ -46,6 +46,17 @@
  *
  * Note: right now, this needs an ANSI C compiler, and might not be 
  *       as portable as the remaining mgetty code.  Send diffs :-)
+ *
+ * $Log: faxq-helper.c,v $
+ * Revision 4.17  2014/02/02 13:44:26  gert
+ * warning cleanup:
+ *   convert all "char" expressions to (uch) when calling ctype.h macros (*sigh*)
+ *   fix signed/unsigned char warning in function calls
+ *
+ * Revision 4.16  2005/04/10 20:47:43  gert
+ * make do_sanitize() work on a copy of the input line
+ * (strtok() modifies the input string, leading to corrupt JOB files)
+ *
  */
 
 #include <stdio.h>
@@ -109,7 +120,7 @@ int validate_job_id( char * JobID )
     if ( *p++ != 'F' ) rc = -1;
     while( *p != '\0' && rc == 0 )
     {
-	if ( ! isdigit( *p ) ) rc = -1;
+	if ( ! isdigit( (unsigned char)*p ) ) rc = -1;
 	p++;
     }
     if ( strlen( JobID ) > MAXJIDLEN ) rc = -1;
@@ -278,7 +289,7 @@ again:
     l = read( fd, buf, sizeof(buf)-1 );
     if ( l >= 0 ) buf[l] = '\0';
 
-    if ( l < 0 || l >= sizeof(buf)-1 || ! isdigit( buf[0] ) )
+    if ( l < 0 || l >= sizeof(buf)-1 || ! isdigit( (unsigned char)buf[0] ) )
     {
 	eout( "sequence file '%s' corrupt\n", FAX_SEQ_FILE );
 	goto close_and_out;
@@ -372,7 +383,9 @@ int fd, r, w;
 
     while( *p != '\0' )
     {
-	if ( *p == '/' || *p == '\\' || isspace(*p) || !isprint(*p) )
+	if ( *p == '/' || *p == '\\' || 
+                isspace( (unsigned char)*p ) || 
+		!isprint( (unsigned char)*p ) )
 	{
 	    eout( "invalid char. '%c' in file name '%s', abort\n",
 		  *p, outfilename );
@@ -491,11 +504,22 @@ int rc = 0;
  */
 int do_sanitize_page_files( char * dir, char * filelist )
 {
-char * p, tmp[300];
+char * p, * copy, tmp[300];
 struct stat stb;
 int n=0;
+int l;
 
-    p = strtok( filelist, " \t\n" );
+    l = strlen(filelist);
+    if ( l == 0 ) return 0;		/* empty list is OK */
+
+    copy = malloc( l+1 );
+    if ( copy == NULL )
+    {
+	eout( "in do_sanitize: cannot malloc() %d bytes, abort\n", l ); return -1;
+    }
+    memcpy( copy, filelist, l+1 );
+
+    p = strtok( copy, " \t\n" );
 
     while( p != NULL )
     {
@@ -536,6 +560,7 @@ int do_activate( char * JID )
 char dir1[MAXJIDLEN+20];
 char buf[1000], *p, *q;
 int fd;
+int user_seen = 0;
 
     if ( isatty(fileno(stdin)) )
 	fprintf(stderr, "NOTICE: reading input from stdin, end with ctrl-D\n");
@@ -566,16 +591,11 @@ int fd;
 	    eout( "input line too long\n" ); break;
 	}
 
-	if ( write( fd, buf, l ) != l )
-	{
-	    eout( "can't write line to JOB file: %s\n", strerror(errno) );
-	    break;
-	}
-
 	if ( l>0 && buf[l-1] == '\n' ) buf[--l]='\0';
 
 	if ( strncmp(buf, "user ", 5) == 0 )
 	{
+	    user_seen=1;
 	    if ( real_user_id != ROOT_UID &&
 		 strcmp( buf+5, real_user_name ) != 0 )
 	    {
@@ -597,14 +617,28 @@ int fd;
 		 *q == '\\' || *q == ';' )
 				    { *q = '_'; }
 	}
+
+        /* and write to JOB file... */
+	buf[l++] = '\n';
+	if ( write( fd, buf, l ) != l )
+	{
+	    eout( "can't write line to JOB file: %s\n", strerror(errno) );
+	    break;
+	}
     }
 
-    close(fd);
     if ( p != NULL )	/* loop aborted */
     {
-	recursive_rm(dir1); return -1;
+        close(fd); recursive_rm(dir1); return -1;
     }
 
+    if ( !user_seen )		/* no "user ..." line in JOB? */
+    {
+	sprintf( buf, "user %.100s\n", real_user_name );
+	write( fd, buf, strlen(buf) );
+    }
+    close(fd);
+
     /* now make directory world-readable & move to final place */
     if ( chmod( dir1, 0755 ) < 0 )
     {
