@@ -1,4 +1,4 @@
-#ident "$Id: fax_lib.h,v 4.19 2007/05/16 15:24:46 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: fax_lib.h,v 4.21 2014/02/02 13:42:59 gert Exp $ Copyright (c) Gert Doering"
 
 
 /* fax_lib.h
@@ -49,7 +49,10 @@ void hylafax_nsf_decode _PROTO(( uch * nsf, int nsfSize ));
 #ifdef __TIO_H__
 int fax_send_page _PROTO(( char * g3_file, int * bytes_sent, TIO * tio,
 			   Post_page_messages ppm, int fd ));
-int fax_send_ppm  _PROTO(( int fd, TIO *tio, Post_page_messages ppm ));
+int fax_send_ppm  _PROTO(( int fd, TIO *tio, 
+			   Post_page_messages ppm, int bytes_sent ));
+int fax1_send_page _PROTO(( char * g3_file, int * bytes_sent, TIO * tio,
+		            Post_page_messages ppm, int fd ));
 #endif
 
 Modem_type fax_get_modem_type _PROTO(( int fd, char * mclass ));
@@ -64,6 +67,7 @@ int fax1_highlevel_receive _PROTO(( int fd, int * pagenum, char * dirlist,
 int fax1_set_l_id _PROTO(( int fd, char * fax_id ));
 int fax1_set_fdcc _PROTO(( int fd, int fine, int max, int min ));
 extern boolean fax1_receive_have_connect;
+int fax1_send_nsf _PROTO(( int fd, int carrier ));
 #endif
 
 /* g3file.c */
