@@ -1,4 +1,4 @@
-#ident "$Id: faxrecp.c,v 1.7 2002/11/23 11:56:48 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxrecp.c,v 1.13 2014/02/02 13:44:19 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxrecp.c - part of mgetty+sendfax
  *
@@ -94,13 +94,13 @@ char	DevId[3];
 
 #ifdef SHORT_FILENAMES
     sprintf(temp, "%s/f%c%07x%s.%02d", directory,
-		 fax_par_d.vr == 0? 'n': 'f',
+		 (fax_par_d.vr == 0 || fax_par_d.vr == 8) ? 'n': 'f',
 	         (int) call_start & 0xfffffff,
 	         DevId, pagenum );
 #else
     /* include sender's fax id - if present - into filename */
     sprintf(temp, "%s/f%c%07x%s-", directory,
-		fax_par_d.vr == 0? 'n': 'f',
+		(fax_par_d.vr == 0 || fax_par_d.vr == 8) ? 'n': 'f',
 		(int) call_start & 0xfffffff,
 		DevId );
     i = strlen(temp);
@@ -110,7 +110,7 @@ char	DevId[3];
     {
 	char c = fax_remote_id[j];
 
-	if ( isalnum(c) ) temp[i++] = c;
+	if ( isalnum( (uch) c) ) temp[i++] = c;
 	else
 	    { if ( temp[i-1] != '-' ) temp[i++] = '-' ; }
     }
@@ -133,6 +133,11 @@ char	DevId[3];
     }
 
     fax_fp = fdopen( fax_fd, "w" );
+    if ( fax_fp == NULL )
+    {
+	lprintf( L_ERROR, "fdopen() %s failed, giving up", temp );
+	return ERROR;
+    }
 
     /* do permission and owner changes as soon as possible -- security */
 
@@ -186,6 +191,7 @@ char	DevId[3];
 	if ( mdm_read_byte( fd, &c ) != 1 )
 	{
 	    lprintf( L_ERROR, "error waiting for page start" );
+	    fclose(fax_fp);
 	    return ERROR;
 	}
 	lputc( L_NOISE, c );
@@ -210,22 +216,25 @@ char	DevId[3];
 	    ErrorCount++;
 	    lprintf( L_ERROR, "fax_get_page_data: cannot read from port (%d)!",
 	                      ErrorCount );
-	    if (ErrorCount > 10) return ERROR;
+	    if (ErrorCount > 10) 
+		{ fclose(fax_fp); return ERROR; }
 	}
 	ByteCount++;
 
 	if ( !WasDLE )
 	{
 	    if ( c == DLE ) WasDLE = 1;
-	               else fputc( c, fax_fp );
+	               else fputc( fax_recv_swaptable[(uch)c], fax_fp );
 	}
 	else	/* WasDLE */
 	{
-	    if ( c == DLE ) fputc( c, fax_fp );		/* DLE DLE -> DLE */
+	    if ( c == DLE ) 				/* DLE DLE -> DLE */
+		fputc( fax_recv_swaptable[(uch)c], fax_fp );
 	    else
 	      if ( c == SUB )				/* DLE SUB -> 2x DLE */
 	    {						/* (class 2.0) */
-		fputc( DLE, fax_fp ); fputc( DLE, fax_fp );
+		fputc( fax_recv_swaptable[DLE], fax_fp ); 
+		fputc( fax_recv_swaptable[DLE], fax_fp ); 
 	    }
 	    else
 	      if ( c == ETX ) break;			/* DLE ETX -> end */
@@ -249,6 +258,44 @@ char	DevId[3];
     return NOERROR;
 }
 
+/* helper function: find a directory in dirlist that has enough free 
+ * disk space (2x minfree). If none has "plenty", use the last one, 
+ * until space in there is less than 1x minfree, then give up.
+ * (if no directory is writeable, we'll fail later on)
+ */
+
+void fax_find_directory _P3((dirlist,directory,size),
+			    char * dirlist, char * directory, int size )
+{
+char *p, *p_help;
+
+    p = dirlist;
+
+    do
+    {
+        int l = strlen(p)+1;
+	if ( l > size-1 ) l=size-1;
+
+    	p_help = memccpy( directory, p, ':', l );
+
+	if ( p_help != NULL ) { *(p_help-1) = '\0'; p++; }
+	directory[l] = '\0';
+	p += strlen(directory);
+
+	if ( access( directory, W_OK ) < 0 )
+	{
+	    lprintf( L_ERROR, "fax_find_dir: can't write to '%s'", directory);
+	    continue;
+	}
+
+        if ( checkspace(directory) > 1 )  { break; }
+
+	lprintf( L_WARN, "fax_find_dir: not enough disk space in '%s'",
+		 directory);
+    }
+    while( *p != '\0' );
+}
+
 /* receive fax pages
  * will return the number of received pages in *pagenum
  */
@@ -260,46 +307,11 @@ int fax_get_pages _P6( (fd, pagenum, dirlist, uid, gid, mode ),
 static const char start_rcv = DC2;
 
     char directory[MAXPATH];
-    char * p, * p_help;
 
-    /* find a directory in dirlist that has enough free disk space
-     * (2x minfree). If none has "plenty", use the last one, until
-     * space in there is less than 1x minfree, then give up.
-     */
-    p = dirlist;
-
-    do
-    {
-        int l = strlen(p)+1;
-	if ( l > sizeof(directory)-1 ) l=sizeof(directory)-1;
-
-    	p_help = memccpy( directory, p, ':', l );
-
-	if ( p_help != NULL ) { *(p_help-1) = '\0'; p++; }
-	directory[l] = '\0';
-	p += strlen(directory);
-
-	if ( access( directory, W_OK ) < 0 )
-	{
-	    lprintf( L_ERROR, "fax_get_pages: can't write to '%s'", directory);
-	    continue;
-	}
-
-        if ( checkspace(directory) > 1 )  { break; }
-
-	lprintf( L_WARN, "fax_get_pages: not enough disk space in '%s'",
-		 directory);
-    }
-    while( *p != '\0' );
+    fax_find_directory( dirlist, directory, sizeof(directory) );
 
     *pagenum = 0;
 
-    /* allocate memory for fax page file names
-     */
-
-    fax_file_names = malloc( fax_fn_size = MAXPATH * 4 );
-    if ( fax_file_names != NULL ) fax_file_names[0] = 0;
-
     if ( fax_poll_req || fax_hangup )
     {
 	lprintf( L_MESG, "fax_get_pages: no pages to receive" );
