@@ -1,4 +1,4 @@
-#ident "$Id: g3cat.c,v 4.4 2003/09/29 21:29:51 gert Exp $ (c) Gert Doering"
+#ident "$Id: g3cat.c,v 4.8 2016/02/09 15:13:31 gert Exp $ (c) Gert Doering"
 
 /* g3cat.c - concatenate multiple G3-Documents
  *
@@ -11,6 +11,23 @@
  *                -a (byte-align EOLs)
  *		  -h <lines> put <lines> empty lines on top of page
  *		  -p <pad>   zero-fill all lines up to <pad> bytes
+ *
+ * $Log: g3cat.c,v $
+ * Revision 4.8  2016/02/09 15:13:31  gert
+ * replace "inline" with "static inline" - C99 compilers interpret naked
+ * inline as "extern inline" and omit function body, so if the function
+ * can not be inlined, it is just plain not there...
+ * (http://stackoverflow.com/questions/216510/extern-inline/216546#216546)
+ *
+ * Revision 4.7  2014/02/02 11:57:59  gert
+ * Michal Sekletar:
+ *   pass actual file descriptor to close(), not negative result from read()
+ *
+ * Revision 4.6  2010/10/08 10:49:23  gert
+ * add CVS Log tag
+ * when reporting invalid code, lseek() on "fd", not on stdin (bugfix) and
+ * use "SEEK_CUR" instead of "1" (easier to read and more portable code)
+ *
  */
 
 /* #define DEBUG 1 */
@@ -44,7 +61,7 @@ static int b_written = 0;		/* bytes of a line already */
 					/* written */
 
 #ifdef __GNUC__
-inline
+static inline
 #endif
 void putcode _P2( (code, len), int code, int len )
 {
@@ -67,7 +84,7 @@ void putcode _P2( (code, len), int code, int len )
 }
 
 #ifdef __GNUC__
-inline
+static inline
 #endif
 void putwhitespan _P1( (l), int l )
 {
@@ -98,7 +115,7 @@ void putwhitespan _P1( (l), int l )
 }
 
 #ifdef __GNUC__
-inline
+static inline
 #endif
 void putblackspan _P1( (l), int l )
 {
@@ -129,7 +146,7 @@ void putblackspan _P1( (l), int l )
 }
 
 #ifdef __GNUC__
-inline
+static inline
 #endif
 void puteol _P0( void )			/* write byte-aligned EOL */
 {
@@ -194,6 +211,9 @@ int main _P2( (argc, argv),
     int empty_lines = 0;	/* blank lines at top of page */
     int line_width = 1728;	/* "force perfect" G3 file */
     int opt_R = 0;		/* suppress generation of RTC */
+    int max_length = 0;		/* limit max. G3 file length */
+
+    int lines_out = 0;		/* total lines in output file */
 
     /* initialize lookup trees */
     build_tree( &white, t_white );
@@ -207,7 +227,7 @@ int main _P2( (argc, argv),
     /* process the command line
      */
 
-    while ( (i = getopt(argc, argv, "lah:p:w:R")) != EOF )
+    while ( (i = getopt(argc, argv, "lah:p:w:RL:")) != EOF )
     {
 	switch (i)
 	{
@@ -217,6 +237,7 @@ int main _P2( (argc, argv),
 	  case 'p': padding = atoi( optarg ); break;
 	  case 'w': line_width = atoi( optarg ); break;
 	  case 'R': opt_R = 1; break;
+	  case 'L': max_length = atoi( optarg ); break;
 	  case '?': exit_usage(argv[0]); break;
 	}
     }
@@ -254,6 +275,7 @@ int main _P2( (argc, argv),
 	    {
 		putwhitespan( line_width );
 		puteol();
+		lines_out++;
 	    }
 	}
 	
@@ -266,7 +288,7 @@ int main _P2( (argc, argv),
 
 	have_warned = 0;
 	rs = read( fd, rbuf, sizeof(rbuf) );
-	if ( rs < 0 ) { perror( "read" ); close( rs ); exit(8); }
+	if ( rs < 0 ) { perror( "read" ); close( fd ); exit(8); }
 
 			    /* skip GhostScript header */
 	rp = ( rs >= 64 && strcmp( rbuf+1, "PC Research, Inc" ) == 0 ) ? 64 : 0;
@@ -326,7 +348,7 @@ int main _P2( (argc, argv),
 	    if ( p == NULL )	/* invalid code */
 	    { 
 		fprintf( stderr, "invalid code, row=%d, col=%d, file offset=%lx, skip to eol\n",
-			 row, col, (unsigned long)lseek( 0, 0, 1 ) - rs + rp );
+			 row, col, (unsigned long)lseek( fd, 0, SEEK_CUR ) - rs + rp );
 		while ( ( data & 0x03f ) != 0 )
 		{
 		    data >>= 1; hibit--;
@@ -418,6 +440,9 @@ int main _P2( (argc, argv),
 		    row++; col=0;
 		    cons_eol = 0;
 		    puteol();
+		    lines_out++;
+		    if ( max_length > 0 && 
+			 lines_out >= max_length ) { goto do_write; }
 		}
 	    }
 	    else		/* not eol, write out code */
@@ -454,6 +479,10 @@ do_write:      		/* write eol, separating lines, next file */
 
 	if( fd != 0 ) close(fd);	/* close input file */
 
+	/* if maximum lines has been reached, leave outer loop */
+	if ( max_length > 0 && 
+	     lines_out >= max_length ) { break; }
+
 #ifdef DEBUG
 	fprintf( stderr, "%s: number of EOLs: %d (%d)\n", argv[i], eols,cons_eols );
 #endif
