@@ -1,12 +1,46 @@
 #ifndef ___MGETTY_H
 #define ___MGETTY_H
 
-#ident "$Id: mgetty.h,v 4.26 2005/02/14 12:41:43 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.h,v 4.35 2018/03/06 11:37:51 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.h
  *
  * contains most of the constants and prototypes necessary for
  * mgetty+sendfax (except some fax constants, they are in fax_lib.h)
+ *
+ * $Log: mgetty.h,v $
+ * Revision 4.35  2018/03/06 11:37:51  gert
+ * Alex Manoussakis: cid-program patch set
+ *
+ * Revision 4.34  2014/01/31 13:02:08  gert
+ * move clean_line() from modem.c to clean_line.c
+ *
+ * Revision 4.33  2014/01/31 10:05:45  gert
+ * add prototype for connect_to_remote_tty()
+ * move clean_line() prototype to "modem.c" section
+ * add port_type_t enum to differenciate modem handling on port type
+ *
+ * Revision 4.32  2014/01/28 12:21:15  gert
+ * add safe_strdup()
+ *
+ * Revision 4.31  2010/09/22 09:00:29  gert
+ * move handle_incoming_sms() prototype from mgetty.h to mgetty.c - the easy
+ * way to work around uid_t and gid_t not being defined in all .c files
+ *
+ * Revision 4.30  2010/09/17 15:37:06  gert
+ * add new action enums: A_SMS_IN, A_SMS_REPORT (SMS handler)
+ * add prototype for handle_incoming_sms() -> sms.c
+ *
+ * Revision 4.29  2005/12/31 15:52:45  gert
+ * move typedef...uch from class1.h to mgetty.h
+ *
+ * Revision 4.28  2005/11/26 13:48:16  gert
+ * GNU/kFreeBSD portability changes
+ *
+ * Revision 4.27  2005/04/25 15:29:20  gert
+ * proper prototype for rmlocks()
+ * set SIG_HDLR_ARGS correctly on AIX5 (needs -DAIX5 in CFLAGS)
+ *
  */
 
 #include "ugly.h"
@@ -114,13 +148,14 @@ int lprintf _PROTO((int level, const char *format, ...));
  */
 typedef	void	RETSIGTYPE;
 
-#ifdef _SCO_DS		/* SCO OSR 5.0 */
+#if defined(_SCO_DS) || defined(AIX5)		/* SCO OSR 5.0 */
 # define SIG_HDLR_ARGS	int signo
 #else
 # define SIG_HDLR_ARGS
 #endif
 
 typedef	char	boolean;
+typedef unsigned char uch;
 
 /* the cpp directive "sun" isn't useful at all, since is defined on
  * SunOS 4, Solaris 2, and even Solaris x86...
@@ -195,19 +230,26 @@ typedef	char	boolean;
 
 typedef enum {
 	A_TIMOUT, A_FAIL, A_FAX, A_VCON, A_CONN,
-	A_RING1, A_RING2, A_RING3, A_RING4, A_RING5
+	A_RING1, A_RING2, A_RING3, A_RING4, A_RING5,
+	A_SMS_IN, A_SMS_REPORT
 } action_t;
 
 typedef struct	chat_actions {
 			char * expect;
 			action_t action; } chat_action_t ;
 
+/* what sort of file descriptor are we talking to? */
+typedef enum {
+	PT_TTY, 		/* regular unix tty with POSIX */
+	PT_RAW_SOCKET, 		/* network socket, no modem control */
+	PT_2217_SOCKET		/* network socket, RFC2217, telnet proto */
+} port_type_t;
+
 /* do_chat.c */
 int	do_chat _PROTO(( int filedesc, char * expect_send[],
 	     	 chat_action_t actions[], action_t * action,
 		 int chat_timeout_time, boolean timeout_first ));
 int	do_chat_send _PROTO(( int filedesc, char * send_str_with_esc ));
-int	clean_line _PROTO(( int filedesc, int tenths ));
 
 /* ring.c */
 int	wait_for_ring _PROTO(( int filedesc, char ** msn_list, int timeout, 
@@ -221,6 +263,7 @@ void	get_statistics _PROTO(( int filedesc, char ** chat, char * file ));
 char * get_basename _PROTO(( char * ));
 char * mydup _PROTO(( char *s ));
 char * get_ps_args _PROTO(( int pid ));
+char * safe_strdup _PROTO(( char * ));
 
 /* io.c */
 boolean	check_for_input _PROTO (( int fd ));
@@ -232,7 +275,7 @@ void	delay _PROTO(( int waittime ));
 int		makelock _PROTO((char * device));
 int		makelock_file _PROTO(( char * lockname ));
 int		checklock _PROTO((char * device));
-RETSIGTYPE	rmlocks _PROTO (());
+void		rmlocks _PROTO ((void));
 int		steal_lock _PROTO((char * device, int pid ));
   
 /* fax stuff */
@@ -266,6 +309,14 @@ char *	mdm_get_line  _PROTO(( int fd ));
 int	mdm_command   _PROTO(( char * send, int fd ));
 char *  mdm_get_idstring _PROTO(( char * send, int n, int fd ));
 
+/* clean_line.c */
+int	clean_line _PROTO(( int filedesc, int tenths ));
+
+/* socket.c */
+#ifdef FAX_SEND_SOCKETS
+int connect_to_remote_tty _PROTO(( char * fax_tty ));
+#endif
+
 /* logname.c */
 char *	ln_escape_prompt _PROTO(( char * prompt ));
 void	set_env_var _PROTO(( char * var, char * string ));
@@ -283,6 +334,7 @@ void setup_environment _PROTO(( void ));
 
 extern char *Connect;
 extern char *CallerId;
+extern char *CallDate;
 extern char *CallTime;
 extern char *CallName;
 extern char *CalledNr;
@@ -313,7 +365,7 @@ int getdiskstats _PROTO ((char *path, mntinf *mi));
 extern char * mktemp _PROTO(( char * template ));
 
 #if  !defined(linux) && !defined(SVR4) && !defined(__hpux) && \
-     !defined(BSD) && !defined(M_UNIX) && !defined(_AIX)
+     !defined(BSD) && !defined(M_UNIX) && !defined(_AIX) && !defined(__GLIBC__)
 extern int	getopt _PROTO(( int, char **, char * ));
 #endif
 extern int	optind;
