@@ -1,4 +1,4 @@
-#ident "@(#)policy.h	3.1 95/08/30 Copyright (c) Gert Doering"
+#ident "$Id: policy.h,v 4.28 2018/03/06 11:07:08 gert Exp $ Copyright (c) Gert Doering"
 
 /* this is the file where all configuration defaults for mgetty / sendfax
  * are specified.
@@ -27,14 +27,16 @@
  * to call for what user name.
  *
  * You could use it to call "uucico" for all users starting with "U*"
- * (works only with Taylor UUCP 1.04 with my patch), or to call a fido
- * mailer for fido calls (only if -DFIDO defined)...
+ * (works only with Taylor UUCP 1.04 with my patch), for AutoPPP calls 
+ * being properly dispatched to pppd, or to call a fido mailer for fido 
+ * calls (only if AutoPPP and/or FIDO support are compiled in, see below)...
+ *
+ * If you want to call /bin/login for all data calls, do not define this
+ *
  * See the samples in the example login.config file (built from login.cfg.in).
  *
  * WARNING: make sure that this file isn't world-accessable (SECURITY!)
  *
- * If you want to call /bin/login in any case, do not define this
- *
  * If this doesn't start with "/", it's relative to CONFDIR.
  */
 #define LOGIN_CFG_FILE "login.config"
@@ -48,6 +50,42 @@
  */
 #define DEFAULT_LOGIN_PROGRAM "/bin/login"
 
+/* FidoNet mailer support
+ * 
+ * If you want to support incoming FidoNet calls, define FIDO.
+ *
+ * (If you don't know what this is, you don't want it)
+ */
+/* #define FIDO */
+
+/* AutoPPP-Support
+ *
+ * If you want to auto-detect incoming PPP calls (with authorization done
+ * by the pppd, i.e. via CHAP or PAP), define AUTO_PPP.
+ * Not needed if PPP callers want to get a real "login:"
+ * prompt first. Don't forget to activate the /AutoPPP/ line in login.config!
+ */
+/* #define AUTO_PPP */
+
+/* SMS support
+ *
+ * if you want to use mgetty on a GSM modem and handle incoming SMS
+ * messages and/or SMS status reports, enable this.  This will add extra
+ * code to mgetty to recognize +CMTI: and +CDSI: messages, and some extra
+ * options (sms-handler*) to control dispatching to external scripts.
+ */
+/* #define SMS */
+
+/* callback config file
+ *
+ * this file controls the operation of the optional "callback" program.
+ * how callback works, is explained in detail in mgetty.texi. You need
+ * to set LOGIN_CFG_FILE (see above) to use callback from mgetty. 
+ *
+ * If this path does not start with "/", it's relative to CONFDIR.
+ */
+#define CALLBACK_CONFIG "callback.config"
+
 
 /* if this file exists, it can be used to control what callers
  * are allowed in.  If undefined, the functionality is omitted.
@@ -81,11 +119,11 @@
 /* user id of the "uucp" user. The tty device will be owned by this user,
  * so parallel dial-out of uucico will be possible
  */
-#define DEVICE_OWNER	"root"
+#define DEVICE_OWNER	"uucp"
 /* group id that the device is chown()ed to. If not defined, the
  * primary group of "DEVICE_OWNER" is used.
  */
-#define DEVICE_GROUP	"dialout"
+#define DEVICE_GROUP	"modem"
 
 /* access mode for the line while getty has it - it should be accessible
  * by uucp / uucp, but not by others (imagine someone dialing into your
@@ -95,7 +133,11 @@
 
 /* security: optionally, mgetty can system() this, to kill any dangling
  * processes on the current tty. A %s is replaced with the tty device.
- * NOT NEEDED on SCO, SunOS 4 or Linux!
+ * 
+ * Under most circumstances, this is not needed.  You might want
+ * to use it if you offer dial-in services with shell accounts to people
+ * that you don't trust (they might try to abuse your modems, and this
+ * will stop a number of attacks).
  */
 /* #define EXEC_FUSER "exec fuser -k -f %s >/dev/null 2>&1" */
 
@@ -103,19 +145,22 @@
 /* logging */
 
 /* system console - if a severe error happens at startup, mgetty writes
- * a message to this file and aborts
+ * a message to this file and aborts - typically "/dev/console"
  * On SCO, this may be /dev/syscon!
+ * (if this functionality is not wanted or does not work, use /dev/null)
  */
-#define CONSOLE "/dev/console"
+#define CONSOLE "/dev/null"
 
 /* Name of the mgetty log file
- * e.g. "/usr/spool/log/mgetty.log.%s"
+ * e.g. "/usr/spool/log/mgetty.log.%s" or "/tmp/log_mg.%s"
  * a "%s" will be replaced by the device name, e.g. "tty2a"
+ *
+ * if the directory does not exist, the log file goes to CONSOLE (!)
  */
-#define LOG_PATH "/var/log/mgetty/mg_%s.log"
+#define LOG_PATH "/var/log/mgetty.%s"
 
 /* Default log error level threshold. Possible error levels are
- * L_FATAL, L_ERROR, L_WARN, L_AUDIT, L_MESG, L_NOISE, L_JUNK (see mgetty.h)
+ * L_FATAL, L_ERROR, L_AUDIT, L_WARN, L_MESG, L_NOISE, L_JUNK (see mgetty.h)
  */
 #define LOG_LEVEL L_MESG
 
@@ -137,7 +182,7 @@
  * mgetty will use the facility "LOG_AUTH", and the priorities
  * LOG_NOTICE, LOG_ERR and LOG_ALERT, respectively.
  */
-#define SYSLOG
+/* #define SYSLOG */
 
 /* Syslog facility
  *
@@ -161,18 +206,18 @@
  */
 #define LOGIN_PROMPT	"@!login: "
 
-/* On SVR4, maybe on other systems too, you can cause the 'login' program
- * to prompt with the same string as mgetty did, instead of the standard
- * "login:" prompt. The string will be passed to the 'login' program
- * in the environment variable TTYPROMPT.
- * This is done by putting "login" into a special (brain-dead) "ttymon"-
- * compatibility mode. In that mode, mgetty doesn't ask for a login name
- * at all, so mgetty won't work if you enable that feature and your
- * login program doesn't support it. (You can see if it doesn't work
- * if the user gets a double login prompt or none at all).
- * To use that feature, define ENV_TTYPROMPT.
+/* The old '#define ENV_TTYPROMPT' option has been superseded by setting 
+ * "login-env-ttyprompt-hack yes" in mgetty.config.  See mgetty.texi for
+ * details.
  */
-/* #define ENV_TTYPROMPT */
+
+/* Some very old terminals can only generate UPPERCASE letters.
+ * Traditional getty variants detect this, and then set the
+ * corresponding termio(s) flags to convert upper/lower case letters
+ * "on the fly".  Mgetty can do it, but since this is hardly
+ * needed nowadays, the default is off.
+ */
+/* #define DO_LCUC_MAP */
 
 /* Maximum time before login name has to be entered (in seconds)
  * (after that time a warning will be issued, after that, the call is
@@ -190,12 +235,6 @@
 
 /* misc */
 
-/* how to find mgetty..
- *
- * If you define this, mgetty will create a file with the given name and
- * put its process ID in it. A "%s" will be replaced by the device id.
- */
-#define MGETTY_PID_FILE	"/var/run/mg-pid.%s"
 
 /* Path for the lock files. A %s will be replaced with the device name,
  * e.g. tty2a -> /usr/spool/uucp/LCK..tty2a
@@ -217,11 +256,17 @@
 # ifdef NeXT
 #  define LOCK "/usr/spool/uucp/LCK/LCK..%s"
 # endif
+# ifdef linux
+#  define LOCK	"/var/lock/LCK..%s"
+# endif
+# if defined(__FreeBSD__) || defined(__NetBSD__)
+#  define LOCK "/var/spool/lock/LCK..%s"
+# endif 
 #endif
 
 /* if your system isn't listed above, change that line here */
 #ifndef LOCK
-#define LOCK "/var/lock/LCK..%s"
+#define LOCK "/usr/spool/uucp/LCK..%s"
 #endif
   
 /* Set this to "1" if your system uses binary lock files (i.e., the pid
@@ -277,7 +322,7 @@
  *
  * The modem must answer with "OK" (!!!) - otherwise, use "init-chat".
  */
-#define MODEM_INIT_STRING "AT"
+#define MODEM_INIT_STRING	"ATS0=0Q0&D3&C1"
 
 /* command termination string
  *
@@ -335,8 +380,8 @@
 /* incoming faxes will be chown()ed to this uid and gid.
  * if FAX_IN_GROUP is undefined, the group of ...OWNER is used.
  */
-#define FAX_IN_OWNER	"root"
-#define FAX_IN_GROUP	"fax"
+#define FAX_IN_OWNER	"uucp"
+/* #define FAX_IN_GROUP	"root" */
 
 /* incoming faxes will be chmod()ed to this mode
  * (if you do not define this, the file mode will be controlled by
@@ -385,7 +430,7 @@
  * in most of the received faxes.
  * Most faxmodems expect Xon/Xoff, few honour the RTS line.
  */
-#define FAXREC_FLOW	FLOW_SOFT
+#define FAXREC_FLOW	FLOW_HARD | FLOW_SOFT
 
 /* And this is for sending faxes
  *
@@ -398,8 +443,13 @@
  * If you see a large number of [11] and [13] characters in the sendfax
  * log file, your modem is propably doing software flow control - and
  * you've definitely set FAXSEND_FLOW to FLOW_HARD...
+ *
+ * Some versions of SCO Unix have a "weird" serial driver that will only
+ * do half duplex hardware flow control. You will then run into the problem
+ * that fax sending will time out after the first page sent (no ACK received)
+ * and fail if FLOW_HARD is used. Use FLOW_SOFT instead.
  */
-#define FAXSEND_FLOW	FLOW_SOFT
+#define FAXSEND_FLOW	FLOW_HARD | FLOW_SOFT
  
 /* if your faxmodem switches port bit rate just after sending the "+FCON"
  * message to the host, define this to contain the baudrate used. (Not
@@ -412,20 +462,12 @@
  * starts the fax receiver, and times out waiting for OK, receiving
  * nothing or just junk.
  */
-#define FAX_RECV_SWITCHBD 19200
-
-/* some genius at US Robotics obviously decided that the above method
- * of switching baud rates is broken, and came up with something new
- * --- broken as well (why bother switching rates at all?) --- this
- * and other USR Courier Fax follies will be handled by enabling the
- * following define (if you have an USR faxmodem that does *not* need
- * this, please send me a mail!)
- * It seems as if the newest V.34 modems do not need this anymore, please
- * try it out...
- */
-/* #define FAX_USRobotics */
+/* #define FAX_RECV_SWITCHBD 19200 */
 
 /* name of the logfile for outgoing faxes (e.g. /var/log/sendfax.log)
+ *
+ * watch out: if you run 'sendfax' as non-privileged user (user 'fax' etc.)
+ * you might need to create this file manually and chown it to 'fax'
  */
 #define FAX_LOG		"/var/log/sendfax.log"
 
@@ -434,7 +476,7 @@
  * but some do only allow digits and blank
  * AT+FLID=? should tell you what's allowed and what not.
  */
-#define FAX_STATION_ID	" "
+#define FAX_STATION_ID	"49 115 xxxxxxxx"
 
 /* ------ sendfax-specific stuff follows here -------- */
 
@@ -493,22 +535,10 @@
 /* the device(s) used for faxing
  * multiple devices can be separated by ":", e.g. "tty1a:tty2a"
  * (with or without leading /dev/)
+ * If you don't adapt this for your needs, sendfax won't run (you can
+ * set it from the sendfax.config file, though)!
  */
-#define FAX_MODEM_TTYS	"ttyS1"
-
-/* some modems, notably some GVC modems and the german telecom approved
- * ZyXEL EG+ have the annoying behaviour of lowering and raising the
- * DCD line during the pre- and post-page handshake (when sending).
- *
- * If your modem does this, sendfax will terminate immediately after
- * starting to send the first page, or between the first and second
- * page, and the fax log file will show something like
- * "read failed, I/O error".
- *
- * If you define this, sendfax will (try to) ignore that line
- */
-
-/* #define FAX_SEND_IGNORE_CARRIER */
+#define FAX_MODEM_TTYS	"tty4c:tty4d"
 
 /* Xon or not?
  *
@@ -518,38 +548,32 @@
  *
  * If you get an error message "... waiting for XON" when trying to
  * send a fax, try this one. Some ELSA modems are know to need it.
+ *
+ * ** THIS OPTION IS OBSOLETE **  
+ * ** use "modem-quirks 0x08" in sendfax.config instead **
  */
-/* #define FAXSEND_NO_XON */
 
 
-/* define mailer that accepts destination on command line and mail text
- * on stdin. For mailers with user friendly interfaces, (such as mail,
- * mailx, elm), include an appropriate subject line in the command
- * definition. If using a mail agent (such as sendmail), that reads
- * mail headers, define NEED_MAIL_HEADERS.
+/* define mail transport agent to use for incoming fax notifications
+ * normally, this will be "sendmail -t -i" (which works for all common
+ * mail transport packages), with the receipient put into the "To:"
+ * line on stdin.
+ * If your mail client needs to have the receipient address on the
+ * command line, define NEED_MAIL_TO_ON_CLI.
  */
-#ifdef SVR4
-# define MAILER		"/usr/bin/mailx -s 'Incoming facsimile message'"
-#else
-# ifdef _AIX
-#  define MAILER	"/usr/sbin/sendmail"
-#  define NEED_MAIL_HEADERS
-# endif
-# ifdef M_UNIX		/* SCO */
-#  define MAILER	"/usr/lib/mail/execmail"
-#  define NEED_MAIL_HEADERS
-# endif
+#ifdef M_UNIX		/* SCO */
+# define MAILER	"/usr/lib/mail/execmail"
+# define NEED_MAIL_TO_ON_CLI
 #endif
 
 #ifndef MAILER
-# define MAILER		"/usr/lib/sendmail"
-# define NEED_MAIL_HEADERS
+# define MAILER		"/usr/sbin/sendmail -t -i"
 #endif
 
 /* where to send notify mail about incoming faxes to
  * (remember to create an mail alias if no such user exists!)
  */
-#define MAIL_TO		"root"
+#define MAIL_TO		"faxadmin"
 
 /* after a fax has arrived, mgetty can call a program for further
  * processing of this fax.
@@ -564,10 +588,30 @@
  * If you don't want this type of service, do not define it at all
  * Absolute path name has to be used here!
  */
-#define FAX_NOTIFY_PROGRAM "/usr/lib/mgetty+sendfax/new_fax"
+#define FAX_NOTIFY_PROGRAM "/usr/local/lib/mgetty+sendfax/new_fax"
 
 /* default minimum space required on spooling partition for receiving a FAX
  * (in KILObytes)
  */
 #define	MINFREESPACE 1024
 
+/* fax machines exchange so-called "non-standard-frames" that can be 
+ * used to identify what vendor and model is on the other end.
+ * mgetty parses and prints this by default, because it can help 
+ * troubleshooting - but the tables use up memory.  
+ * If you're very tight on RAM, disable this (saves about 10 Kbyte).
+ */
+#define FAX_NSF_PARSER
+
+/* enable sendfax to access a modem that's connected on a different
+ * machine in the network, using ser2net (or something similar) to 
+ * provide mapping from tcp/ip connection to local /dev/tty* device
+ *
+ * the code is hacky - ttyRI<n><mm> is mapped to a socket call to
+ * host "isdnserver<n>" and port 50000+<mm>.  There will be better
+ * support via sendfax.config ("port xxx / server ... ") eventually.
+ *
+ * this code assumes a modern socket API with getaddrinfo(), so it's
+ * off-by-default as it might break on older systems
+ */
+/* #define FAX_SEND_SOCKETS */
