@@ -1,4 +1,4 @@
-#ident "$Id: tio.c,v 4.5 2000/10/22 10:45:20 gert Exp $ Copyright (c) 1993 Gert Doering"
+#ident "@(#)$Id: tio.c,v 4.10 2014/02/02 13:42:40 gert Exp $ Copyright (c) 1993 Gert Doering"
 
 /* tio.c
  *
@@ -18,13 +18,13 @@
 #include "tio.h"
 
 #ifdef POSIX_TERMIOS
-static char tio_compilation_type[]="@(#)tio.c compiled with POSIX_TERMIOS";
+# ident "@(#)tio.c compiled with POSIX_TERMIOS"
 #endif
 #ifdef SYSV_TERMIO
-static char tio_compilation_type[]="@(#)tio.c compiled with SYSV_TERMIO";
+# ident "@(#)tio.c compiled with SYSV_TERMIO"
 #endif
 #ifdef BSD_SGTTY
-static char tio_compilation_type[]="@(#)tio.c compiled with BSD_SGTTY";
+# ident "@(#)tio.c compiled with BSD_SGTTY"
 #endif
 
 #ifdef USE_TERMIOX
@@ -45,7 +45,7 @@ static char tio_compilation_type[]="@(#)tio.c compiled with BSD_SGTTY";
 
 /* some systems do not define all flags needed later, e.g. NetBSD */
 
-#ifdef BSD
+#if defined(BSD) || defined(__FreeBSD_kernel__)
 # ifndef IUCLC
 # define IUCLC 0
 # endif
@@ -58,6 +58,10 @@ static char tio_compilation_type[]="@(#)tio.c compiled with BSD_SGTTY";
 # endif
 #endif
 
+#ifdef BSD
+# include <sys/ioctl.h>
+#endif
+
 /* baud rate table */
 static struct	speedtab {
 #ifdef POSIX_TERMIOS
@@ -203,6 +207,7 @@ int tio_check_speed _P1( (speed), int speed )
 	}
     }
     lprintf( L_NOISE, "speed %d not found in table", speed );
+    errno=EINVAL;
     return -1;
 }
 
