@@ -54,7 +54,7 @@
  *
  * -----------------------------------------------------------------------
  *
- * $Id: rockwell.c,v 1.4 1998/09/09 21:07:03 gert Exp $
+ * $Id: rockwell.c,v 1.6 1999/03/16 09:59:20 marcs Exp $
  *
  */
 
@@ -713,9 +713,11 @@ int pvftorockwell (FILE *fd_in, FILE *fd_out, int nbits, pvf_header *header_in)
 
  /* The rmd header should have been written by now. Do the compression. */
 
- while (!feof(fd_in))
+ while (1)
   {
   w = header_in->read_pvf_data(fd_in);
+  if (feof(fd_in))
+    break;
   /* The pvf routines work on 24bit ints */
   write_bits_reverse(fd_out, &s, nbits, (int)RV_ComOne((vgetty_s_int16)(w>>8)) );
   }
@@ -724,3 +726,41 @@ int pvftorockwell (FILE *fd_in, FILE *fd_out, int nbits, pvf_header *header_in)
 
   return(OK);
 }
+
+/*
+ * I borrowed this code from wav.c - it assumes the pvf is a certain size and
+ * I'm not sure this is a good assumption -- Bill Nugent <whn@topelo.lopi.com>
+ */
+
+int rockwellpcmtopvf (FILE *fd_in, FILE *fd_out, int nbits, pvf_header *header_out)
+{
+  int d;
+  /* 8 bit PCM */
+  while ((d = getc(fd_in)) != EOF)
+   {
+    d -= 0x80;
+    d <<= 16;
+    header_out->write_pvf_data(fd_out, d);
+  }
+  return(OK);
+}
+
+int pvftorockwellpcm (FILE *fd_in, FILE *fd_out, int nbits, pvf_header *header_in)
+{
+  int data;
+  /* 8 bit PCM */
+          
+   while((data = header_in->read_pvf_data(fd_in)) != EOF)
+    {
+      data >>=16;
+
+      if   (data > 0x7f)
+	data = 0x7f;
+
+      if   (data < -0x80)
+	data = -0x80;
+      putc(data+0x80,fd_out);
+  };
+
+  return(OK);
+}
