@@ -4,7 +4,7 @@
  * Hacked by <Harlan.Stenn@pfcs.com>. Maybe will be merged
  * with the other Multitech driver.
  *
- * $Id: Multitech_5634.c,v 1.5 1999/12/02 09:51:29 marcs Exp $
+ * $Id: Multitech_5634.c,v 1.7 2006/09/26 17:17:56 gert Exp $
  *
  */
 
@@ -57,8 +57,8 @@ static int Multitech_5634_init(void)
       * AT+VSD=x,y - Set silence threshold and duration. 0-256, .1sec
       */
 
-     sprintf(buffer, "AT+VSD=%d,%d", /*cvd.rec_silence_threshold.d.i *
-      1 / 100 +*/ 128, cvd.rec_silence_len.d.i);
+     sprintf(buffer, "AT+VSD=%d,%d", /*(int)cvd.rec_silence_threshold.d.i *
+      1 / 100 +*/ 128, (int)cvd.rec_silence_len.d.i);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "setting recording preferences didn't work");
@@ -70,8 +70,7 @@ static int Multitech_5634_init(void)
      if (cvd.transmit_gain.d.i == -1)
           cvd.transmit_gain.d.i = 50;
 
-     sprintf(buffer, "AT+VGT=%d", cvd.transmit_gain.d.i * 144 / 100 +
-      56);
+     sprintf(buffer, "AT+VGT=%d", (int)cvd.transmit_gain.d.i * 144 / 100 + 56);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "setting transmit gain didn't work");
@@ -83,8 +82,7 @@ static int Multitech_5634_init(void)
      if (cvd.receive_gain.d.i == -1)
           cvd.receive_gain.d.i = 50;
 
-     sprintf(buffer, "AT+VGR=%d", cvd.receive_gain.d.i * 144 / 100 +
-      56);
+     sprintf(buffer, "AT+VGR=%d", (int)cvd.receive_gain.d.i * 144 / 100 + 56);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "setting receive gain didn't work");
@@ -93,7 +91,7 @@ static int Multitech_5634_init(void)
      return(OK);
      }
 
-static int Multitech_5634_set_compression(int *compression, int *speed,
+static int Multitech_5634_set_compression(p_int *compression, p_int *speed,
  int *bits)
      {
      char buffer[VOICE_BUF_LEN];
@@ -109,7 +107,7 @@ static int Multitech_5634_set_compression(int *compression, int *speed,
      if (*speed != 8000)
           {
           lprintf(L_WARN, "%s: Illegal sample rate (%d)", voice_modem_name,
-           *speed);
+           (int)*speed);
           return(FAIL);
           }
 
@@ -129,7 +127,7 @@ static int Multitech_5634_set_compression(int *compression, int *speed,
           {
           case 4:
                *bits = 4;
-               sprintf(buffer, "AT+VSM=2,%d", *speed);
+               sprintf(buffer, "AT+VSM=2,%d", (int)*speed);
 
                if (voice_command(buffer, "OK") != VMA_USER_1)
                     return(FAIL);
@@ -137,7 +135,7 @@ static int Multitech_5634_set_compression(int *compression, int *speed,
                break;
           case 132:
                *bits = 4;
-               sprintf(buffer, "AT+VSM=132,%d", *speed);
+               sprintf(buffer, "AT+VSM=132,%d", (int)*speed);
 
                if (voice_command(buffer, "OK") != VMA_USER_1)
                     return(FAIL);
@@ -145,7 +143,7 @@ static int Multitech_5634_set_compression(int *compression, int *speed,
                break;
           default:
                lprintf(L_WARN, "%s: Illegal voice compression method (%d)",
-                voice_modem_name, *compression);
+                voice_modem_name, (int)*compression);
                return(FAIL);
           }
 
@@ -345,6 +343,12 @@ voice_modem_struct Multitech_5634ZBAV =
      (char *) IS_101_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      &Multitech_5634_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -369,6 +373,10 @@ voice_modem_struct Multitech_5634ZBAV =
      &IS_101_wait,
      &IS_101_play_dtmf,
      &IS_101_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      0
      };
 
